@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -279,7 +279,7 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 
 	{ "no-valid-category",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  "This software component is no member of any valid category."
+	  "This software component is no member of any valid category (note that custom categories and toolkit categories like 'Qt' or 'GTK' are ignored)."
 	},
 
 	{ "description-missing",
