@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2018-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2018-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -34,8 +34,7 @@
 
 static gchar *datadir = NULL;
 
-typedef struct
-{
+typedef struct {
 	gchar *path;
 } Fixture;
 
@@ -48,12 +47,12 @@ asc_assert_no_hints_in_result (AscResult *cres)
 	g_autoptr(GPtrArray) hints = asc_result_fetch_hints_all (cres);
 
 	if (hints->len > 0) {
-		g_printerr("--------\nHints:");
+		g_printerr ("--------\nHints:");
 		for (guint i = 0; i < hints->len; i++) {
 			g_autofree gchar *text = NULL;
 			AscHint *hint = ASC_HINT (g_ptr_array_index (hints, i));
 			text = asc_hint_format_explanation (hint);
-			g_printerr("\n%s\n", text);
+			g_printerr ("\n%s\n", text);
 		}
 	}
 	g_assert_cmpint (hints->len, ==, 0);
@@ -121,16 +120,14 @@ test_compose_issue_tag_sanity (void)
 	g_autoptr(GHashTable) tag_map = NULL;
 	g_auto(GStrv) all_hint_tags = NULL;
 
-	tag_map = g_hash_table_new_full (g_str_hash,
-					 g_str_equal,
-					 NULL,
-					 NULL);
+	tag_map = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
 
 	all_hint_tags = asc_globals_get_hint_tags ();
 	for (guint i = 0; all_hint_tags[i] != NULL; i++) {
 		gboolean r = g_hash_table_add (tag_map, all_hint_tags[i]);
 		if (!r) {
-			g_critical ("Duplicate compose issue-tag '%s' found in tag list.", all_hint_tags[i]);
+			g_critical ("Duplicate compose issue-tag '%s' found in tag list.",
+				    all_hint_tags[i]);
 			g_assert_not_reached ();
 		}
 	}
@@ -150,25 +147,51 @@ test_read_fontinfo (void)
 	g_autofree gchar *data = NULL;
 	gsize data_len;
 	g_autoptr(GList) lang_list = NULL;
-	guint i;
-	const gchar *expected_langs[] =  { "aa", "ab", "af", "ak", "an", "ast", "av", "ay", "az-az", "ba", "be", "ber-dz", "bg", "bi", "bin",
-					   "bm", "br", "bs", "bua", "ca", "ce", "ch", "chm", "co", "crh", "cs", "csb", "cu", "cv", "cy", "da",
-					   "de", "ee", "el", "en", "eo", "es", "et", "eu", "fat", "ff", "fi", "fil", "fj", "fo", "fr", "fur",
-					   "fy", "ga", "gd", "gl", "gn", "gv", "ha", "haw", "ho", "hr", "hsb", "ht", "hu", "hz", "ia", "id",
-					   "ie", "ig", "ik", "io", "is", "it", "jv", "kaa", "kab", "ki", "kj", "kk", "kl", "kr", "ku-am",
-					   "ku-tr", "kum", "kv", "kw", "kwm", "ky", "la", "lb", "lez", "lg", "li", "ln", "lt","lv", "mg", "mh",
-					   "mi", "mk", "mn-mn", "mo", "ms", "mt", "na", "nb", "nds", "ng", "nl", "nn", "no", "nr", "nso", "nv",
-					   "ny", "oc", "om", "os", "pap-an", "pap-aw", "pl", "pt", "qu", "quz", "rm", "rn", "ro", "ru", "rw",
-					   "sah", "sc", "sco", "se", "sel", "sg", "sh", "shs", "sk", "sl", "sm","sma", "smj", "smn", "sms", "sn",
-					   "so", "sq", "sr", "ss", "st", "su", "sv", "sw", "tg", "tk", "tl", "tn", "to", "tr", "ts", "tt", "tw",
-					   "ty", "tyv", "uk", "uz", "ve", "vi", "vo", "vot", "wa", "wen", "wo", "xh", "yap", "yo", "za", "zu", NULL };
+	const gchar *expected_langs_old_fontconfig[] = {
+		"aa",	  "ab",	   "af",  "an",	 "ast",	  "av",	   "ay",  "az-az", "ba",  "be",
+		"bg",	  "bi",	   "bin", "br",	 "bs",	  "bua",   "ca",  "ce",	   "ch",  "chm",
+		"co",	  "crh",   "cs",  "csb", "cv",	  "cy",	   "da",  "de",	   "en",  "eo",
+		"es",	  "et",	   "eu",  "fi",	 "fil",	  "fj",	   "fo",  "fr",	   "fur", "fy",
+		"gd",	  "gl",	   "gn",  "gv",	 "haw",	  "ho",	   "hr",  "hsb",   "ht",  "hu",
+		"ia",	  "id",	   "ie",  "ig",	 "ik",	  "io",	   "is",  "it",	   "jv",  "kaa",
+		"ki",	  "kj",	   "kk",  "kl",	 "ku-am", "ku-tr", "kum", "kv",	   "kw",  "kwm",
+		"ky",	  "la",	   "lb",  "lez", "lg",	  "li",	   "lt",  "lv",	   "mg",  "mh",
+		"mk",	  "mn-mn", "mo",  "ms",	 "mt",	  "na",	   "nb",  "nds",   "ng",  "nl",
+		"nn",	  "no",	   "nr",  "nso", "nv",	  "ny",	   "oc",  "om",	   "os",  "pap-an",
+		"pap-aw", "pl",	   "pt",  "qu",	 "quz",	  "rm",	   "rn",  "ro",	   "ru",  "rw",
+		"sah",	  "sc",	   "se",  "sel", "sg",	  "sh",	   "sk",  "sl",	   "sm",  "sma",
+		"smj",	  "smn",   "sn",  "so",	 "sq",	  "sr",	   "ss",  "st",	   "su",  "sv",
+		"sw",	  "tg",	   "tk",  "tl",	 "tn",	  "to",	   "tr",  "ts",	   "tt",  "ty",
+		"tyv",	  "uk",	   "uz",  "vi",	 "vo",	  "vot",   "wa",  "wen",   "wo",  "xh",
+		"yap",	  "za",	   "zu",  NULL
+	};
+	const gchar *expected_langs[] = {
+		"aa",	  "ab",	    "af",  "agr", "an",	 "ast", "av",  "ay",  "ayc",   "az-az",
+		"ba",	  "be",	    "bem", "bg",  "bi",	 "bin", "br",  "bs",  "bua",   "ca",
+		"ce",	  "ch",	    "chm", "co",  "crh", "cs",	"csb", "cv",  "cy",    "da",
+		"de",	  "dsb",    "en",  "eo",  "es",	 "et",	"eu",  "fi",  "fil",   "fj",
+		"fo",	  "fr",	    "fur", "fy",  "gd",	 "gl",	"gn",  "gv",  "haw",   "ho",
+		"hr",	  "hsb",    "ht",  "hu",  "ia",	 "id",	"ie",  "ig",  "ik",    "io",
+		"is",	  "it",	    "jv",  "kaa", "ki",	 "kj",	"kk",  "kl",  "ku-am", "ku-tr",
+		"kum",	  "kv",	    "kw",  "kwm", "ky",	 "la",	"lb",  "lez", "lg",    "li",
+		"lij",	  "lt",	    "lv",  "mfe", "mg",	 "mh",	"mhr", "miq", "mjw",   "mk",
+		"mn-mn",  "mo",	    "ms",  "mt",  "na",	 "nb",	"nds", "ng",  "nhn",   "niu",
+		"nl",	  "nn",	    "no",  "nr",  "nso", "nv",	"ny",  "oc",  "om",    "os",
+		"pap-an", "pap-aw", "pl",  "pt",  "qu",	 "quz", "rm",  "rn",  "ro",    "ru",
+		"rw",	  "sah",    "sc",  "se",  "sel", "sg",	"sgs", "sh",  "sk",    "sl",
+		"sm",	  "sma",    "smj", "smn", "sn",	 "so",	"sq",  "sr",  "ss",    "st",
+		"su",	  "sv",	    "sw",  "szl", "tg",	 "tk",	"tl",  "tn",  "to",    "tpi",
+		"tr",	  "ts",	    "tt",  "ty",  "tyv", "uk",	"unm", "uz",  "vi",    "vo",
+		"vot",	  "wa",	    "wae", "wen", "wo",	 "xh",	"yap", "yuw", "za",    "zu",
+		NULL
+	};
 
-	font_fname = g_build_filename (datadir, "NotoSans-Regular.ttf", NULL);
+	font_fname = g_build_filename (datadir, "Raleway-Regular.ttf", NULL);
 
 	/* test reading from file */
 	font = asc_font_new_from_file (font_fname, &error);
 	g_assert_no_error (error);
-	g_assert_cmpstr (asc_font_get_family (font), ==, "Noto Sans");
+	g_assert_cmpstr (asc_font_get_family (font), ==, "Raleway");
 	g_assert_cmpstr (asc_font_get_style (font), ==, "Regular");
 	g_object_unref (font);
 	font = NULL;
@@ -177,28 +200,61 @@ test_read_fontinfo (void)
 	g_file_get_contents (font_fname, &data, &data_len, &error);
 	g_assert_no_error (error);
 
-	font = asc_font_new_from_data (data, data_len, "NotoSans-Regular.ttf", &error);
+	font = asc_font_new_from_data (data, data_len, "Raleway-Regular.ttf", &error);
 	g_assert_no_error (error);
-	g_assert_cmpstr (asc_font_get_family (font), ==, "Noto Sans");
+	g_assert_cmpstr (asc_font_get_family (font), ==, "Raleway");
 	g_assert_cmpstr (asc_font_get_style (font), ==, "Regular");
 	g_assert_cmpint (asc_font_get_charset (font), ==, FT_ENCODING_UNICODE);
-	g_assert_cmpstr (asc_font_get_homepage (font), ==, "http://www.monotype.com/studio");
-	g_assert_cmpstr (asc_font_get_description (font), ==, "Data hinted. Designed by Monotype design team.");
+	g_assert_cmpstr (asc_font_get_homepage (font), ==, "http://pixelspread.com");
+	g_assert_cmpstr (asc_font_get_description (font),
+			 ==,
+			 "Raleway is an elegant sans-serif typeface family. "
+			 "Initially designed by Matt McInerney as a single thin weight, "
+			 "it was expanded into a 9 weight family by Pablo Impallari and "
+			 "Rodrigo Fuenzalida in 2012 and iKerned by Igino Marini. "
+			 "It is a display face and the download features both old style "
+			 "and lining numerals, standard and discretionary ligatures, a "
+			 "pretty complete set of diacritics, as well as a stylistic "
+			 "alternate inspired by more geometric sans-serif typefaces "
+			 "than its neo-grotesque inspired default character set.");
 
 	lang_list = asc_font_get_language_list (font);
-	i = 0;
-	for (GList *l = lang_list; l != NULL; l = l->next) {
-		g_assert_true (expected_langs[i] != NULL);
-		g_assert_cmpstr (expected_langs[i], ==, l->data);
-		i++;
+
+	{
+		guint i = 0;
+		gboolean fc_lang_success = TRUE;
+		for (GList *l = lang_list; l != NULL; l = l->next) {
+			g_assert_nonnull (expected_langs_old_fontconfig[i]);
+			if (!as_str_equal0 (expected_langs_old_fontconfig[i], l->data)) {
+				fc_lang_success = FALSE;
+				break;
+			}
+			i++;
+		}
+		if (!fc_lang_success) {
+			i = 0;
+			for (GList *l = lang_list; l != NULL; l = l->next) {
+				g_assert_nonnull (expected_langs[i]);
+				g_assert_cmpstr (expected_langs[i], ==, l->data);
+				i++;
+			}
+		}
 	}
 
 	/* uses "Noto Sans" */
-	g_assert_cmpstr (asc_font_get_sample_text (font), ==, "My grandfather picks up quartz and valuable onyx jewels.");
-	g_assert_cmpstr (asc_font_find_pangram(font, "en", "Noto Sans"), ==, "My grandfather picks up quartz and valuable onyx jewels.");
+	g_assert_cmpstr (asc_font_get_sample_text (font),
+			 ==,
+			 "A mad boxer shot a quick, gloved jab to the jaw of his dizzy opponent.");
+	g_assert_cmpstr (asc_font_find_pangram (font, "en", "Raleway"),
+			 ==,
+			 "A mad boxer shot a quick, gloved jab to the jaw of his dizzy opponent.");
 
-	g_assert_cmpstr (asc_font_find_pangram(font, "en", "aaaaa"), ==, "Pack my box with five dozen liquor jugs.");
-	g_assert_cmpstr (asc_font_find_pangram(font, "en", "abcdefg"), ==, "Five or six big jet planes zoomed quickly past the tower.");
+	g_assert_cmpstr (asc_font_find_pangram (font, "en", "aaaaa"),
+			 ==,
+			 "Pack my box with five dozen liquor jugs.");
+	g_assert_cmpstr (asc_font_find_pangram (font, "en", "abcdefg"),
+			 ==,
+			 "Five or six big jet planes zoomed quickly past the tower.");
 }
 
 /**
@@ -227,10 +283,7 @@ test_image_transform (void)
 	sample_img_fname = g_build_filename (datadir, "appstream-logo.png", NULL);
 
 	/* load image from file */
-	image = asc_image_new_from_file (sample_img_fname,
-					 0,
-					 ASC_IMAGE_LOAD_FLAG_NONE,
-					 &error);
+	image = asc_image_new_from_file (sample_img_fname, 0, ASC_IMAGE_LOAD_FLAG_NONE, &error);
 	g_assert_no_error (error);
 	g_assert_nonnull (image);
 
@@ -243,10 +296,11 @@ test_image_transform (void)
 	g_assert_cmpint (asc_image_get_height (image), ==, 64);
 
 	ret = asc_image_save_filename (image,
-				      "/tmp/asc-iscale_test.png",
-				      0, 0,
-				      ASC_IMAGE_SAVE_FLAG_NONE,
-				      &error);
+				       "/tmp/asc-iscale_test.png",
+				       0,
+				       0,
+				       ASC_IMAGE_SAVE_FLAG_NONE,
+				       &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
 
@@ -257,7 +311,8 @@ test_image_transform (void)
 	g_file_get_contents (sample_img_fname, &data, &data_len, &error);
 	g_assert_no_error (error);
 
-	image = asc_image_new_from_data (data, data_len,
+	image = asc_image_new_from_data (data,
+					 data_len,
 					 0,
 					 FALSE,
 					 ASC_IMAGE_LOAD_FLAG_NONE,
@@ -267,10 +322,11 @@ test_image_transform (void)
 
 	asc_image_scale (image, 124, 124);
 	ret = asc_image_save_filename (image,
-				      "/tmp/asc-iscale-d_test.png",
-				      0, 0,
-				      ASC_IMAGE_SAVE_FLAG_NONE,
-				      &error);
+				       "/tmp/asc-iscale-d_test.png",
+				       0,
+				       0,
+				       ASC_IMAGE_SAVE_FLAG_NONE,
+				       &error);
 	g_assert_no_error (error);
 	g_assert_true (ret);
 }
@@ -311,17 +367,19 @@ test_canvas (void)
 	cv = NULL;
 
 	/* test font rendering */
-	font_fname = g_build_filename (datadir, "NotoSans-Regular.ttf", NULL);
+	font_fname = g_build_filename (datadir, "Raleway-Regular.ttf", NULL);
 	font = asc_font_new_from_file (font_fname, &error);
 	g_assert_no_error (error);
 
 	cv = asc_canvas_new (400, 100);
 
-	asc_canvas_draw_text (cv,
-			      font,
-			      "Hello World!\nSecond Line!\nThird line - äöüß!\nA very, very, very long line.",
-			      -1, -1,
-			      &error);
+	asc_canvas_draw_text (
+	    cv,
+	    font,
+	    "Hello World!\nSecond Line!\nThird line - äöüß!\nA very, very, very long line.",
+	    -1,
+	    -1,
+	    &error);
 	g_assert_no_error (error);
 
 	asc_canvas_save_png (cv, "/tmp/asc-fontrender_test1.png", &error);
@@ -346,7 +404,9 @@ test_compose_hints (void)
 
 	g_assert_cmpstr (asc_hint_get_tag (hint), ==, "internal-unknown-tag");
 	g_assert_cmpint (asc_hint_get_severity (hint), ==, AS_ISSUE_SEVERITY_ERROR);
-	g_assert_cmpstr (asc_hint_get_explanation_template (hint), ==, "The given tag was unknown. Please file an issue against AppStream.");
+	g_assert_cmpstr (asc_hint_get_explanation_template (hint),
+			 ==,
+			 "The given tag was unknown. Please file an issue against AppStream.");
 	g_assert_true (asc_hint_is_valid (hint));
 	g_assert_true (asc_hint_is_error (hint));
 
@@ -355,15 +415,19 @@ test_compose_hints (void)
 	g_assert_true (asc_hint_is_valid (hint));
 	g_assert_true (!asc_hint_is_error (hint));
 
-	asc_hint_set_explanation_template (hint,
-					   "This is an explanation for {{name}} which contains {{amount}} placeholders, "
-					   "including one {odd} one and one left {{invalid}} intentionally.");
+	asc_hint_set_explanation_template (
+	    hint,
+	    "This is an explanation for {{name}} which contains {{amount}} placeholders, "
+	    "including one {odd} one and one left {{invalid}} intentionally.");
 	asc_hint_add_explanation_var (hint, "name", "the compose testsuite");
 	asc_hint_add_explanation_var (hint, "amount", "3");
 
 	tmp = asc_hint_format_explanation (hint);
-	g_assert_cmpstr (tmp, ==, "This is an explanation for the compose testsuite which contains 3 placeholders, "
-				  "including one {odd} one and one left {{invalid}} intentionally.");
+	g_assert_cmpstr (
+	    tmp,
+	    ==,
+	    "This is an explanation for the compose testsuite which contains 3 placeholders, "
+	    "including one {odd} one and one left {{invalid}} intentionally.");
 }
 
 /**
@@ -389,9 +453,12 @@ test_compose_result (void)
 	g_assert_no_error (error);
 	g_assert_true (ret);
 
-	ret = asc_result_add_hint (cres, cpt,
+	ret = asc_result_add_hint (cres,
+				   cpt,
 				   "x-dev-testsuite-info",
-				   "var1", "testvalue-info", NULL);
+				   "var1",
+				   "testvalue-info",
+				   NULL);
 	g_assert_true (ret);
 
 	g_assert_cmpint (asc_result_components_count (cres), ==, 1);
@@ -402,9 +469,12 @@ test_compose_result (void)
 
 	g_assert_true (asc_result_get_component (cres, "org.freedesktop.appstream.dummy") == cpt);
 
-	ret = asc_result_add_hint (cres, cpt,
+	ret = asc_result_add_hint (cres,
+				   cpt,
 				   "x-dev-testsuite-error",
-				   "var1", "testvalue-error", NULL);
+				   "var1",
+				   "testvalue-error",
+				   NULL);
 	g_assert_false (ret);
 
 	/* component no longer exists after an error, so this should fail now */
@@ -443,13 +513,14 @@ test_compose_desktop_entry (void)
 	gchar *tmp;
 	AsLaunchable *launch;
 	GPtrArray *hints;
-	g_autoptr(GBytes) de_bytes = as_gbytes_from_literal ("[Desktop Entry]\n"
-							     "Type=Application\n"
-							     "Name=FooBar\n"
-							     "Name[de_DE]=FööBär\n"
-							     "Comment=A foo-ish bar.\n"
-							     "Keywords=Hobbes;Bentham;Locke;\n"
-							     "Keywords[de_DE]=Heidegger;Kant;Hegel;\n");
+	g_autoptr(GBytes) de_bytes = as_gbytes_from_literal (
+	    "[Desktop Entry]\n"
+	    "Type=Application\n"
+	    "Name=FooBar\n"
+	    "Name[de_DE]=FööBär\n"
+	    "Comment=A foo-ish bar.\n"
+	    "Keywords=Hobbes;Bentham;Locke;\n"
+	    "Keywords[de_DE]=Heidegger;Kant;Hegel;\n");
 
 	cres = asc_result_new ();
 
@@ -459,8 +530,9 @@ test_compose_desktop_entry (void)
 					    de_bytes,
 					    "foobar.desktop",
 					    FALSE, /* don't ignore nodisplay */
-					    AS_FORMAT_VERSION_CURRENT,
-					    NULL, NULL);
+					    AS_FORMAT_VERSION_LATEST,
+					    NULL,
+					    NULL);
 	g_assert_nonnull (cpt);
 	g_clear_pointer (&cpt, g_object_unref);
 
@@ -480,8 +552,9 @@ test_compose_desktop_entry (void)
 					    de_bytes,
 					    "org.example.foobar.desktop",
 					    FALSE, /* don't ignore nodisplay */
-					    AS_FORMAT_VERSION_CURRENT,
-					    NULL, NULL);
+					    AS_FORMAT_VERSION_LATEST,
+					    NULL,
+					    NULL);
 	g_assert_nonnull (cpt);
 	g_clear_pointer (&cpt, g_object_unref);
 
@@ -507,8 +580,9 @@ test_compose_desktop_entry (void)
 					    de_bytes,
 					    "org.example.foobar.desktop",
 					    TRUE, /* ignore nodisplay */
-					    AS_FORMAT_VERSION_CURRENT,
-					    NULL, NULL);
+					    AS_FORMAT_VERSION_LATEST,
+					    NULL,
+					    NULL);
 	g_assert_nonnull (cpt);
 	g_clear_pointer (&cpt, g_object_unref);
 
@@ -520,9 +594,8 @@ test_compose_desktop_entry (void)
 	g_assert_cmpstr (as_component_get_name (cpt), ==, "TestX");
 	g_assert_cmpstr (as_component_get_summary (cpt), ==, "Summary of TestX");
 
-
-	as_component_set_active_locale (cpt, "C.UTF-8");
-	tmp = g_strjoinv (", ", as_component_get_keywords (cpt));
+	as_component_set_context_locale (cpt, "C.UTF-8");
+	tmp = as_ptr_array_strjoin (as_component_get_keywords (cpt), ", ");
 	g_assert_cmpstr (tmp, ==, "Hobbes, Bentham, Locke");
 	g_free (tmp);
 
@@ -531,7 +604,9 @@ test_compose_desktop_entry (void)
 	g_assert_nonnull (launch);
 
 	g_assert_cmpint (as_launchable_get_entries (launch)->len, ==, 1);
-	g_assert_cmpstr (g_ptr_array_index (as_launchable_get_entries (launch), 0), ==, "org.example.foobar.desktop");
+	g_assert_cmpstr (g_ptr_array_index (as_launchable_get_entries (launch), 0),
+			 ==,
+			 "org.example.foobar.desktop");
 	g_clear_pointer (&cpt, g_object_unref);
 
 	/* from file with damaged UTF-8 */
@@ -547,19 +622,27 @@ test_compose_desktop_entry (void)
 					    de_bytes2,
 					    "gnome-breakout.desktop",
 					    FALSE, /* don't ignore nodisplay */
-					    AS_FORMAT_VERSION_CURRENT,
-					    NULL, NULL);
+					    AS_FORMAT_VERSION_LATEST,
+					    NULL,
+					    NULL);
 	g_assert_nonnull (cpt);
 
-	as_component_set_active_locale (cpt, "C.UTF-8");
+	as_component_set_context_locale (cpt, "C.UTF-8");
 	g_assert_cmpstr (as_component_get_name (cpt), ==, "GNOME Breakout");
-	g_assert_cmpstr (as_component_get_summary (cpt), ==, "Play a clone of the classic arcade game Breakout for GNOME");
-	as_component_set_active_locale (cpt, "de");
+	g_assert_cmpstr (as_component_get_summary (cpt),
+			 ==,
+			 "Play a clone of the classic arcade game Breakout for GNOME");
+	as_component_set_context_locale (cpt, "de");
 	g_assert_cmpstr (as_component_get_name (cpt), ==, "GNOME Breakout");
-	g_assert_cmpstr (as_component_get_summary (cpt), ==, "Play a clone of the classic arcade game Breakout for GNOME"); /* not loaded, contains bad UTF-8 */
-	as_component_set_active_locale (cpt, "tr");
+	g_assert_cmpstr (
+	    as_component_get_summary (cpt),
+	    ==,
+	    "Play a clone of the classic arcade game Breakout for GNOME"); /* not loaded, contains bad UTF-8 */
+	as_component_set_context_locale (cpt, "tr");
 	g_assert_cmpstr (as_component_get_name (cpt), ==, "Gnome Breakout");
-	g_assert_cmpstr (as_component_get_summary (cpt), ==, "Play a clone of the classic arcade game Breakout for GNOME");
+	g_assert_cmpstr (as_component_get_summary (cpt),
+			 ==,
+			 "Play a clone of the classic arcade game Breakout for GNOME");
 
 	/* we should have two warnings about the bad UTF-8 */
 	g_assert_cmpint (asc_result_hints_count (cres), ==, 2);
@@ -623,7 +706,7 @@ test_compose_directory_unit (void)
 	g_assert_cmpint (contents->len, ==, 15);
 	as_sort_strings (contents);
 
-	g_assert_cmpstr (g_ptr_array_index (contents, 0), ==, "/Noto.LICENSE");
+	g_assert_cmpstr (g_ptr_array_index (contents, 0), ==, "/Raleway-Regular.ttf");
 	g_assert_cmpstr (g_ptr_array_index (contents, 5), ==, "/table.svgz");
 
 	/* read existent data */
@@ -631,7 +714,7 @@ test_compose_directory_unit (void)
 	data = asc_unit_read_data (ASC_UNIT (dirunit), "/usr/dummy", &error);
 	g_assert_no_error (error);
 	g_assert_nonnull (data);
-	g_assert_cmpstr ((const gchar*) g_bytes_get_data (data, NULL), ==, "Hello Universe!\n");
+	g_assert_cmpstr ((const gchar *) g_bytes_get_data (data, NULL), ==, "Hello Universe!\n");
 
 	/* read nonexistent data */
 	g_bytes_unref (data);
@@ -674,10 +757,7 @@ test_compose_locale_stats (void)
 	g_assert_true (ret);
 
 	/* try loading a Gettext translation */
-	asc_read_translation_status (cres,
-					ASC_UNIT (dirunit),
-					"/usr",
-					25);
+	asc_read_translation_status (cres, ASC_UNIT (dirunit), "/usr", 25);
 	asc_assert_no_hints_in_result (cres);
 	g_assert_cmpint (as_component_get_language (cpt, "en_GB"), ==, 100);
 	g_assert_cmpint (as_component_get_language (cpt, "ru"), ==, 33);
@@ -691,10 +771,7 @@ test_compose_locale_stats (void)
 	as_translation_set_id (tr, "kdeapp1/translations/kdeapp");
 	as_component_add_translation (cpt, tr);
 
-	asc_read_translation_status (cres,
-					ASC_UNIT (dirunit),
-					"/usr",
-					25);
+	asc_read_translation_status (cres, ASC_UNIT (dirunit), "/usr", 25);
 	asc_assert_no_hints_in_result (cres);
 	g_assert_cmpint (as_component_get_language (cpt, "fr"), ==, 100);
 	g_assert_cmpint (as_component_get_language (cpt, "de"), ==, -1);
@@ -708,10 +785,7 @@ test_compose_locale_stats (void)
 	as_translation_set_id (tr, "kdeapp2/translations/kdeapp");
 	as_component_add_translation (cpt, tr);
 
-	asc_read_translation_status (cres,
-					ASC_UNIT (dirunit),
-					"/usr",
-					25);
+	asc_read_translation_status (cres, ASC_UNIT (dirunit), "/usr", 25);
 	asc_assert_no_hints_in_result (cres);
 	g_assert_cmpint (as_component_get_language (cpt, "fr"), ==, 100);
 	g_assert_cmpint (as_component_get_language (cpt, "de"), ==, -1);
@@ -722,10 +796,7 @@ test_compose_locale_stats (void)
 	as_translation_set_id (tr, "kdeapp3");
 	as_component_add_translation (cpt, tr);
 
-	asc_read_translation_status (cres,
-					ASC_UNIT (dirunit),
-					"/usr",
-					25);
+	asc_read_translation_status (cres, ASC_UNIT (dirunit), "/usr", 25);
 	asc_assert_no_hints_in_result (cres);
 	g_assert_cmpint (as_component_get_language (cpt, "fr"), ==, 100);
 	g_assert_cmpint (as_component_get_language (cpt, "de"), ==, 100);
@@ -763,10 +834,7 @@ test_compose_source_locale (void)
 	g_assert_true (ret);
 
 	/* try loading a Gettext translation */
-	asc_read_translation_status (cres,
-					ASC_UNIT (dirunit),
-					"/usr",
-					25);
+	asc_read_translation_status (cres, ASC_UNIT (dirunit), "/usr", 25);
 	asc_assert_no_hints_in_result (cres);
 	g_assert_cmpint (as_component_get_language (cpt, "en_GB"), ==, 100);
 	g_assert_cmpint (as_component_get_language (cpt, "ru"), ==, 33);
@@ -797,7 +865,8 @@ test_compose_video_info (void)
 	g_assert_true (ret);
 
 	if (asc_globals_get_ffprobe_binary () == NULL) {
-		g_print ("WARNING: Skipping video info test because `ffprobe` binary was not found in PATH!\n");
+		g_print ("WARNING: Skipping video info test because `ffprobe` binary was not found "
+			 "in PATH!\n");
 		return;
 	}
 
@@ -849,7 +918,12 @@ test_compose_font (void)
 	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_METAINFO);
 	{
 		g_autoptr(GFile) file = NULL;
-		g_autofree gchar *fname = g_build_filename (datadir, "usr", "share", "metainfo", "org.example.fonttest.metainfo.xml", NULL);
+		g_autofree gchar *fname = g_build_filename (datadir,
+							    "usr",
+							    "share",
+							    "metainfo",
+							    "org.example.fonttest.metainfo.xml",
+							    NULL);
 		file = g_file_new_for_path (fname);
 		ret = as_metadata_parse_file (mdata, file, AS_FORMAT_KIND_XML, &error);
 		g_assert_no_error (error);
@@ -867,14 +941,50 @@ test_compose_font (void)
 	icon_policy = asc_icon_policy_new ();
 	asc_process_fonts (cres,
 			   ASC_UNIT (dirunit),
+			   "/usr",
 			   export_tmpdir,
 			   NULL, /* no icon export dir */
 			   icon_policy,
-			   ASC_COMPOSE_FLAG_STORE_SCREENSHOTS |
-			   ASC_COMPOSE_FLAG_PROCESS_FONTS);
+			   ASC_COMPOSE_FLAG_STORE_SCREENSHOTS | ASC_COMPOSE_FLAG_PROCESS_FONTS);
 	asc_assert_no_hints_in_result (cres);
 }
 
+static void
+test_compose_icon_policy_serialize (void)
+{
+	g_autoptr(AscIconPolicy) ipolicy = NULL;
+	g_autofree gchar *tmp = NULL;
+	gboolean ret;
+	g_autoptr(GError) error = NULL;
+
+	ipolicy = asc_icon_policy_new ();
+	tmp = asc_icon_policy_to_string (ipolicy);
+	g_assert_cmpstr (tmp,
+			 ==,
+			 "48x48=cached,48x48@2=cached,64x64=cached,64x64@2=cached,"
+			 "128x128=cached-remote,128x128@2=cached-remote");
+	g_free (g_steal_pointer (&tmp));
+
+	ret = asc_icon_policy_from_string (
+	    ipolicy,
+	    "48x48@2=ignored,64x64=cached,64x64@2=cached-remote,128x128=remote,128x128@2=remote",
+	    &error);
+	g_assert_no_error (error);
+	g_assert_true (ret);
+	g_clear_error (&error);
+
+	tmp = asc_icon_policy_to_string (ipolicy);
+	g_assert_cmpstr (
+	    tmp,
+	    ==,
+	    "48x48@2=ignored,64x64=cached,64x64@2=cached-remote,128x128=remote,128x128@2=remote");
+	g_free (g_steal_pointer (&tmp));
+
+	ret = asc_icon_policy_from_string (ipolicy, "48x48-2:ignored,64x64:cached", &error);
+	g_assert_error (error, AS_UTILS_ERROR, AS_UTILS_ERROR_FAILED);
+	g_assert_false (ret);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -895,7 +1005,12 @@ main (int argc, char **argv)
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
-	g_test_add ("/AppStream/Compose/OptipngNotfound", Fixture, NULL, setup, test_compose_optipng_not_found, teardown);
+	g_test_add ("/AppStream/Compose/OptipngNotfound",
+		    Fixture,
+		    NULL,
+		    setup,
+		    test_compose_optipng_not_found,
+		    teardown);
 	g_test_add_func ("/AppStream/Compose/Utils", test_utils);
 	g_test_add_func ("/AppStream/Compose/IssueTagSanity", test_compose_issue_tag_sanity);
 	g_test_add_func ("/AppStream/Compose/FontInfo", test_read_fontinfo);
@@ -909,6 +1024,8 @@ main (int argc, char **argv)
 	g_test_add_func ("/AppStream/Compose/SourceLocale", test_compose_source_locale);
 	g_test_add_func ("/AppStream/Compose/VideoInfo", test_compose_video_info);
 	g_test_add_func ("/AppStream/Compose/Font", test_compose_font);
+	g_test_add_func ("/AppStream/Compose/IconPolicySerialize",
+			 test_compose_icon_policy_serialize);
 
 	ret = g_test_run ();
 	g_free (datadir);
